@@ -4,8 +4,8 @@ use Pcore qw[-class];
 use Pcore::Src::File;
 use Term::ANSIColor qw[:constants];
 
-has action => ( is => 'ro', isa => Enum [qw[decompress compress obfuscate hg-pre-commit]], required => 1 );
-has source => ( is => 'ro', isa => Str );    # q[-] - stdin, Str - path
+has action => ( is => 'ro', isa => Enum [qw[decompress compress obfuscate commit]], required => 1 );
+has path => ( is => 'ro', isa => Maybe [Str] );
 
 # mandatory, if source path is idr
 has type => ( is => 'ro', isa => Enum [ map { lc $_->{type} } Pcore::Src::File->cfg->{FILE_TYPE}->@* ] );
@@ -13,87 +13,189 @@ has type => ( is => 'ro', isa => Enum [ map { lc $_->{type} } Pcore::Src::File->
 # mandatory, if source is stdin
 has filename => ( is => 'ro', isa => Str );
 
+# read list of filenames from stdin
+has stdin_files => ( is => 'ro', isa => Bool, default => 0 );
+
 has dry_run     => ( is => 'ro', isa => Bool, default => 0 );
 has interactive => ( is => 'rw', isa => Bool, default => 0 );    # print report to STDOUT
+has no_critic   => ( is => 'ro', isa => Bool, default => 0 );    # skip Perl::Critic filter
 
 has exit_code => ( is => 'rw', isa => Int, default => 0, init_arg => undef );
 has _total_report => ( is => 'lazy', isa => HashRef, default => sub { {} }, init_arg => undef );
 
-sub run {
-    my $self = shift;
+# CLI
+sub cli_help ($self) {
+    return <<'TXT';
+- convert to uft-8;
+- strip BOM header;
+- convert tabs to spaces;
+- trim trailing spaces;
+- trim trailing empty strings;
+- convert line endings to unix style (\x0A);
 
-    if ( $self->action eq 'hg-pre-commit' ) {                    # mercurial pretxncommit hook
-        $self->_action_hg_pre_commit;
+Exit codes:
+
+    0 - source is valid;
+    1 - run-time error;
+    2 - params error;
+    3 - source error;
+TXT
+}
+
+sub cli_opt ($self) {
+    return {
+        action => {
+            desc => <<'TXT',
+action to perform:
+    decompress   unpack sources, DEFAULT;
+    compress     pack sources, comments will be deleted;
+    obfuscate    applied only for javascript and embedded javascripts, comments will be deleted;
+    commit       SCM commit hook
+TXT
+            isa     => [qw[decompress compress obfuscate commit]],
+            min     => 1,
+            default => 'decompress',
+        },
+        type => {
+            desc => 'define source files to process. Mandatory, if <source> is a directory. Recognized types: perl, html, css, js',
+            isa  => [qw[perl html css js]],
+        },
+        stdin_files => {
+            short   => undef,
+            desc    => 'read list of filenames from STDIN',
+            default => 0,
+        },
+        filename => {
+            desc => 'mandatory, if read source content from STDIN',
+            type => 'Str',
+        },
+        no_critic => {
+            short   => undef,
+            desc    => 'skip Perl::Critic filter',
+            default => 0,
+        },
+        dry_run => {
+            short   => undef,
+            desc    => q[don't save changes],
+            default => 0,
+        },
+        pause => {
+            short   => undef,
+            desc    => q[don't close console after script finished],
+            default => 0,
+        },
+    };
+}
+
+sub cli_arg ($self) {
+    return [
+        {   name => 'path',
+            isa  => 'Path',
+            min  => 0,
+        }
+    ];
+}
+
+sub cli_run ( $self, $opt, $arg, $rest ) {
+    P->file->chdir( $PROC->{START_DIR} );
+
+    my $exit_code = try {
+        my $src = Pcore::Src->new(
+            {   interactive => 1,
+                path        => $arg->{path},
+                action      => $opt->{action},
+                stdin_files => $opt->{stdin_files},
+                no_critic   => $opt->{no_critic},
+                dry_run     => $opt->{dry_run},
+                ( exists $opt->{type}     ? ( type     => $opt->{type} )     : () ),
+                ( exists $opt->{filename} ? ( filename => $opt->{filename} ) : () ),
+            }
+        );
+
+        return $src->run;
     }
-    else {
-        $self->_throw_error(q["source" is mandatory]) if !$self->source;
+    catch {
+        my $e = shift;
 
-        if ( $self->source eq q[-] ) {                           # STDIN mode
-            $self->_throw_error(q["filename" is mandatory if source is STDIN]) if !$self->filename;
+        say $e;
+
+        return Pcore::Src::File->cfg->{EXIT_CODES}->{RUNTIME_ERROR};
+    };
+
+    if ( $opt->{pause} ) {
+        print 'Press ENTER to continue...';
+        <STDIN>;
+    }
+
+    exit $exit_code;
+}
+
+# RUN
+sub run ($self) {
+    if ( $self->action eq 'commit' ) {
+        $self->{action} = 'decompress';
+
+        $self->{type} = 'perl';
+    }
+
+    if ( !$self->path ) {    # STDIN mode
+        if ( $self->stdin_files ) {
+            $self->_source_stdin_files;
+        }
+        else {
+            $self->_throw_error(q["filename" is mandatory when source is STDIN]) if !$self->filename;
 
             $self->_source_stdin;
         }
+    }
+    else {
+        $self->_throw_error(q["path" should be readable]) if !-e $self->path;
+
+        if ( -d $self->path ) {    # directory mode
+            $self->_throw_error(q["type" is required when path is directory]) if !$self->type;
+
+            $self->_source_dir;
+        }
         else {
-            $self->_throw_error(q["source" should be readable]) if !-e $self->source;
-
-            if ( -d $self->source ) {                            # directory mode
-                $self->_throw_error(q["type" is required]) if !$self->type;
-
-                $self->_source_dir;
-            }
-            else {
-                $self->_source_file;
-            }
+            $self->_source_file;
         }
     }
 
     return $self->exit_code;
 }
 
-sub _action_hg_pre_commit ($self) {
-    require Pcore::Src::Mercurial;
+sub _source_stdin_files ($self) {
+    my $files = P->file->read_lines(*STDIN);
 
-    my $hg = Pcore::Src::Mercurial->new( { source => $PROC->{START_DIR} } );
+    # index files, calculate max_path_len
+    my @paths_to_process;
 
-    unless ( $hg->root ) {
-        $self->_throw_error(q[No hg repository found]);
+    my $max_path_len = 0;
+
+    for my $path ( $files->@* ) {
+        $path = P->path( $path, is_dir => 0 );
+
+        my $type = Pcore::Src::File->detect_filetype($path);
+
+        next if !$type || lc $type->{type} ne $self->type;    # skip file, if file type isn't supported
+
+        push @paths_to_process, $path;
+
+        $max_path_len = length $path if length $path > $max_path_len;
     }
-    else {
-        # get commit info
-        my $pre_commit = $hg->hg_pre_commit;
 
-        # index files, calculate max_path_len
-        my @paths_to_process;
+    # process files
+    my $filter_args = { $self->no_critic ? ( perl_critic => 0 ) : () };
 
-        my $max_path_len = 0;
-
-        for my $file ( $pre_commit->{files}->@* ) {
-            next if !$file->is_added && !$file->is_modified;
-
-            my $type = Pcore::Src::File->detect_filetype( $file->path );
-
-            next if !$type || $type->{type} ne 'Perl';    # only perl sources processed now
-
-            push @paths_to_process, $file->path;
-
-            $max_path_len = length $file->path if length $file->path > $max_path_len;
-        }
-
-        # process files
-        {
-            my $chdir_guard = P->file->chdir( $hg->root ) or die;
-
-            for (@paths_to_process) {
-                $self->_process_file(
-                    $max_path_len,
-                    action      => 'decompress',
-                    path        => $_->to_string,
-                    is_realpath => 1,
-                    dry_run     => $self->dry_run,
-                    filter_args => { $pre_commit->{message} =~ /#\s*no\scritic/sm ? ( perl_critic => 0 ) : () },
-                );
-            }
-        }
+    for (@paths_to_process) {
+        $self->_process_file(
+            $max_path_len,
+            action      => $self->action,
+            path        => $_->to_string,
+            is_realpath => 1,
+            dry_run     => $self->dry_run,
+            filter_args => $filter_args,
+        );
     }
 
     $self->_report_total if $self->interactive;
@@ -105,17 +207,7 @@ sub _source_stdin ($self) {
     $self->interactive(0);
 
     # read STDIN
-    my $in_buffer;
-
-    {
-        open my $stdin_raw, '<&STDIN' or die;
-
-        binmode $stdin_raw, ':raw' or die;
-
-        $in_buffer = P->file->read_bin($stdin_raw);
-
-        close $stdin_raw or die;
-    }
+    my $in_buffer = P->file->read_bin(*STDIN);
 
     my $res = $self->_process_file(
         undef,
@@ -127,15 +219,7 @@ sub _source_stdin ($self) {
     );
 
     # write STDOUT
-    {
-        open my $stdout_raw, '>&STDOUT' or die;
-
-        binmode $stdout_raw, ':raw' or die;
-
-        print {$stdout_raw} $res->out_buffer->$*;
-
-        close $stdout_raw or die;
-    }
+    print $res->out_buffer->$*;
 
     return;
 }
@@ -147,23 +231,20 @@ sub _source_dir ($self) {
 
     my $max_path_len = 0;
 
-    P->file->finddepth(
-        {   wanted => sub {
-                return if -d;
+    P->file->find(
+        $self->path,
+        dir => 0,
+        sub ($path) {
+            my $type = Pcore::Src::File->detect_filetype($path);
 
-                my $path = P->path( $_, is_dir => 0 );
+            return if !$type || lc $type->{type} ne $self->type;    # skip file, if file type isn't supported
 
-                my $type = Pcore::Src::File->detect_filetype($path);
+            push @paths_to_process, $path;
 
-                return if !$type || lc $type->{type} ne $self->type;    # skip file, if file type isn't supported
+            $max_path_len = length $path if length $path > $max_path_len;
 
-                push @paths_to_process, $path;
-
-                $max_path_len = length $path if length $path > $max_path_len;
-            },
-            no_chdir => 1
-        },
-        $self->source,
+            return;
+        }
     );
 
     # process indexed files
@@ -184,9 +265,9 @@ sub _source_dir ($self) {
 
 sub _source_file ($self) {
     $self->_process_file(
-        length $self->source,
+        length $self->path,
         action      => $self->action,
-        path        => $self->source,
+        path        => $self->path,
         is_realpath => 1,
         dry_run     => $self->dry_run,
     );
@@ -194,23 +275,20 @@ sub _source_file ($self) {
     return;
 }
 
-sub _throw_error {
-    my $self = shift;
-    my $msg = shift || q[Unknown error];
-
+sub _throw_error ( $self, $msg = 'Unknown error' ) {
     die $msg . $LF;
 }
 
-sub _set_exit_code {
-    my $self      = shift;
-    my $exit_code = shift;
-
+sub _set_exit_code ( $self, $exit_code ) {
     $self->exit_code($exit_code) if $exit_code > $self->exit_code;
+
     return $self->exit_code;
 }
 
-sub _process_file ( $self, $max_path_len, % ) {
-    my $res = Pcore::Src::File->new( { @_[ 2 .. $#_ ] } )->run;
+sub _process_file ( $self, $max_path_len, %args ) {
+    my $path = ref $args{path} ? $args{path} : P->path( $args{path} );
+
+    my $res = Pcore::Src::File->new( { %args, path => $path->encoded } )->run;    ## no critic qw[ValuesAndExpressions::ProhibitCommaSeparatedStatements]
 
     $self->_set_exit_code( $res->severity_range_is('ERROR') ? Pcore::Src::File->cfg->{EXIT_CODES}->{SOURCE_ERROR} : Pcore::Src::File->cfg->{EXIT_CODES}->{SOURCE_VALID} );
 
@@ -238,7 +316,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
 
     # print report
     print $hl;
-    printf q[%-*s], $max_path_len, $res->path;
+    printf q[%-*s], $max_path_len, P->text->decode( $res->path->to_string, encoding => $Pcore::WIN_ENC )->$*;
     print q[ ] x 2;
     print RESET;
 
@@ -293,7 +371,7 @@ sub _wrap_color ( $self, $str, $color ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 246                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 324                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -304,7 +382,7 @@ __END__
 
 =head1 NAME
 
-Pcore::Src
+Pcore::Src - Source formatter
 
 =head1 SYNOPSIS
 
